netapp_ontap.models.performance_metric_reduced_throughput API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.performance_metric_reduced_throughput`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class PerformanceMetricReducedThroughputSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the PerformanceMetricReducedThroughput object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `duration: str GET`

    The duration over which this sample is calculated. The time durations are represented in the ISO-8601 standard format. Samples can be calculated over the following durations:

    Valid choices:

    - PT15S
    - PT4M
    - PT30M
    - PT2H
    - P1D
    - PT5M
  `iops: PerformanceMetricIoType GET`

    The iops field of the performance_metric_reduced_throughput.

  `latency: PerformanceMetricIoType GET`

    The latency field of the performance_metric_reduced_throughput.

  `links: SelfLink GET`

    The links field of the performance_metric_reduced_throughput.

  `status: str GET`

    Any errors associated with the sample. For example, if the aggregation of data over multiple nodes fails then any of the partial errors might be returned, "ok" on success, or "error" on any internal uncategorized failure. Whenever a sample collection is missed but done at a later time, it is back filled to the previous 15 second timestamp and tagged with "backfilled_data". "Inconsistent_ delta_time" is encountered when the time between two collections is not the same for all nodes. Therefore, the aggregated value might be over or under inflated. "Negative_delta" is returned when an expected monotonically increasing value has decreased in value. "Inconsistent_old_data" is returned when one or more nodes do not have the latest data.

    Valid choices:

    - ok
    - error
    - partial_no_data
    - partial_no_response
    - partial_other_error
    - negative_delta
    - not_found
    - backfilled_data
    - inconsistent_delta_time
    - inconsistent_old_data
    - partial_no_uuid
  `throughput: PerformanceMetricIoTypeRwt GET`

    The throughput field of the performance_metric_reduced_throughput.

  `timestamp: ImpreciseDateTime GET`

    The timestamp of the performance data.

    Example: 2017-01-25T11:20:13.000+0000